@@ -33,7 +33,7 @@ class TransactionPipeResultOptions(pydantic.BaseModel):
 class MessageTransaction(pydantic.BaseModel):
     fnc: Callable
     args: Optional[Dict]
-    pipe_result_options: Optional[Union[Callable, TransactionPipeResultOptions]]
+    pipe_result_options: Optional[TransactionPipeResultOptions]
 
 
 class MessagePipeline(pydantic.BaseModel):
@@ -68,16 +68,11 @@ class MessagePipeline(pydantic.BaseModel):
                         message = tx.fnc(message, self.logger, **kwargs)
 
                 if tx.pipe_result_options:
-                    if inspect.isfunction(tx.pipe_result_options):
-                        pipe_result_options: TransactionPipeResultOptions = tx.pipe_result_options(message, self.logger,
-                                                                                                   **kwargs)
-                    else:
-                        pipe_result_options: TransactionPipeResultOptions = tx.pipe_result_options
-                    if pipe_result_options.with_response_options:
+                    if tx.pipe_result_options.with_response_options:
                         message = await self.pipe_event_with_response(message, emitter, message_key_as_event,
-                                                                      pipe_result_options, **kwargs)
+                                                                      tx.pipe_result_options, **kwargs)
                     else:
-                        self.pipe_event(message, emitter, message_key_as_event, pipe_result_options, **kwargs)
+                        self.pipe_event(message, emitter, message_key_as_event, tx.pipe_result_options, **kwargs)
         except Exception as e:
             self.logger.error(f'execute => Exception: '
                               f'type: {sys.exc_info()[0]}; '
@@ -470,7 +465,7 @@ class KafkaApp:
                                            f'to: {topic}; '
                                            f'event_id: {event_id}')
         except Exception as e:
-            self.logger.error(f'txn_es_common => Exception: '
+            self.logger.error(f'emit_with_response => Exception: '
                               f'type: {sys.exc_info()[0]}; '
                               f'line#: {sys.exc_info()[2].tb_lineno}; '
                               f'msg: {str(e)}')
